unit AmountUnit;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, ExtCtrls, Buttons;

type
  TAmountForm = class(TForm)
    OutputSelection: TRadioGroup;
    BudgetParameters: TGroupBox;
    Edit1: TEdit;
    Edit2: TEdit;
    Label1: TLabel;
    Label2: TLabel;
    Label3: TLabel;
    Label4: TLabel;
    Edit3: TEdit;
    Edit4: TEdit;
    RangeParameters: TGroupBox;
    Label5: TLabel;
    Label6: TLabel;
    Label7: TLabel;
    Label8: TLabel;
    Edit5: TEdit;
    Edit6: TEdit;
    Edit7: TEdit;
    Edit8: TEdit;
    BitBtn1: TBitBtn;
    Label9: TLabel;
    Edit9: TEdit;
    Label10: TLabel;
    Edit10: TEdit;
    procedure GiveConstraints(Sender: TObject);
    procedure GetAmounts(Sender: TObject);
    procedure ReadAmounts(Sender: TObject);
    procedure SetAmounts;
  private
    { Private declarations }
  public
    { Public declarations }
    AmountFormError: Boolean;
  end;

var
  AmountForm: TAmountForm;

implementation

uses Pintfm;


{$R *.DFM}


procedure TAmountForm.GiveConstraints(Sender: TObject);
var i: integer;
begin
  with PintForm do for i:=1 to 9 do explanation.lines[i] := '';
  BitBtn1.visible := true;
  case OutputSelection.ItemIndex of
   0: begin
        RangeParameters.visible := false;
        BudgetParameters.visible := true;
        with PintForm do begin
          explanation.lines[2] := 'For option 1, the sampling cost is of the form c*N + n*N';
          explanation.lines[3] := 'where N is the number of level-2 units (groups),';
          explanation.lines[4] := 'n is the number of level-1 units per group,';
          explanation.lines[5] := 'and c the cost of sampling another level-2 unit';
          explanation.lines[6] := ' relative to the cost of sampling one level-1 unit.';
          explanation.lines[7] := 'The total budget is the maximal value for c*N + n*N.';
          explanation.lines[8] := 'Also the minimum and maximum group sizes must be given.';
         end; (* with PintForm *)
        Application.ProcessMessages;
       end; (* case 0 *)
   1: begin
        BudgetParameters.visible := false;
        RangeParameters.visible := true;
        with PintForm do begin
          explanation.lines[2] := 'For option 2, the standard errors are given';
          explanation.lines[3] := 'for sample sizes on levels 1 and 2';
          explanation.lines[4] := 'in a range specified by the user.';
          explanation.lines[5] := 'The group size (= number of level-1 units per level-2 unit)';
          explanation.lines[6] := 'should be at least 5;';
          explanation.lines[7] := 'the number of groups (= level-2 units)';
          explanation.lines[8] := 'should be at least 5.';
         end; (* with PintForm *)
        Application.ProcessMessages;
        end; (* case 1 *)
  end; (* case *)
end;

procedure TAmountForm.SetAmounts;
begin
  if BudgetConstraint then OutputSelection.ItemIndex := 0
   else OutputSelection.ItemIndex := 1;
  Edit1.text := inttostr(c);
  Edit2.text := inttostr(bud);
  Edit3.text := inttostr(nmin);
  Edit4.text := inttostr(nmax);
  Edit5.text := inttostr(n2min);
  Edit6.text := inttostr(n2max);
  Edit7.text := inttostr(nmin);
  Edit8.text := inttostr(nmax);
  Edit9.text := inttostr(nstep);
  Edit10.text := inttostr(nstep);
  Edit2.Hint := 'must be at least '+inttostr((nmin+c)*n2min);
  Application.ProcessMessages;
end;

procedure TAmountForm.GetAmounts(Sender: TObject);
begin
  ReadAmounts(Sender);
  if AmountFormError then ModalResult := mrCancel else Modalresult := mrOK;
end;

procedure TAmountForm.ReadAmounts(Sender: TObject);
var x: real;
    code: integer;
begin
  AmountFormError:= false;
  case OutputSelection.ItemIndex of
   0: begin
        BudgetConstraint := true;
        val(Edit1.text,x,code);
        if (code = 0) then c := round(x) else begin
          c := 10; AmountFormerror := true; end;
        if (c < 0) then c := 0;
        val(Edit2.text,x,code);
        if (code = 0) then bud := round(x) else begin
          bud := 1000; AmountFormerror := true; end;
        val(Edit3.text,x,code);
        if (code = 0) then nmin := round(x) else begin
          nmin := 5; AmountFormerror := true; end;
        if (nmin < 1) then nmin := 1;
        val(Edit4.text,x,code);
        if (code = 0) then nmax := round(x) else begin
          nmax := 5; AmountFormerror := true; end;
        if (nmax < nmin) then nmax := nmin;
        val(Edit10.text,x,code);
        if (code = 0) then nstep := round(x) else begin
          nstep := 5; AmountFormerror := true; end;
        if (nstep < 1) then nstep := 1;
        if (bud < ((nmin+c)*n2min)) then bud := (nmin+c)*n2min;
       end; (* case 1 *)
   1: begin
        BudgetConstraint := false;
        val(Edit5.text,x,code);
        if (code = 0) then n2min := round(x) else begin
          n2min := 5; AmountFormerror := true; end;
        if (n2min < 1) then n2min := 1;
        val(Edit6.text,x,code);
        if (code = 0) then n2max := round(x) else begin
          n2max := 50; AmountFormerror := true; end;
        if (n2max < n2min) then n2max := n2min;
        val(Edit7.text,x,code);
        if (code = 0) then nmin := round(x) else begin
          nmin := 5; AmountFormerror := true; end;
        if (nmin < 1) then nmin := 1;
        val(Edit8.text,x,code);
        if (code = 0) then nmax := round(x) else begin
          nmax := 5; AmountFormerror := true; end;
        if (nmax < nmin) then nmax := nmin;
        val(Edit9.text,x,code);
        if (code = 0) then nstep := round(x) else begin
          nstep := 5; AmountFormerror := true; end;
        if (nstep < 1) then nstep := 1;
       end; (* case 1 *)
   end; (* case *)
  SetAmounts;
end;

end.
